API docs for “spamfighter.core.test.test_counters.CounterTestCase”

# Class s.c.t.t.CounterTestCase(unittest.TestCase):

Part of spamfighter.core.test.test_counters View Source View In Hierarchy

Тест на `spamfighter.core.counters.Counter`.

Method | tearDown | Undocumented
Method | testInterface | Undocumented
Method | testStr | Undocumented
Method | testPickling | Undocumented

def tearDown(self): (source)
Undocumented
def testInterface(self): (source)
Undocumented
def testStr(self): (source)
Undocumented
def testPickling(self): (source)
Undocumented